TextEncoder
===========

.. currentmodule:: pykeen.nn.text

.. autoclass:: TextEncoder
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~TextEncoder.encode_all
      ~TextEncoder.forward
      ~TextEncoder.forward_normalized

   .. rubric:: Methods Documentation

   .. automethod:: encode_all
   .. automethod:: forward
   .. automethod:: forward_normalized
